@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_natural;
 
-our $DATE = '2016-06-14'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2016-06-30'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,7 @@ sub meta {
         enable_by_default => 0,
         might_die => 1,
         prio => 60, # a bit lower than normal
-        precludes => [qr/\Astr_alami(_.+)?\z/],
+        precludes => [qr/\A(str_alami(_.+)?|str_flexible)\z/],
     };
 }
 
@@ -34,7 +34,9 @@ sub coerce {
     $res->{modules}{"DateTime::Format::Natural"} //= 0;
     $res->{expr_coerce} = join(
         "",
-        "do { my \$res = DateTime::Format::Natural->new(time_zone => ".dmp($time_zone).")->parse_datetime($dt); ",
+        "do { my \$p = DateTime::Format::Natural->new(time_zone => ".dmp($time_zone)."); my \$res = \$p->parse_datetime($dt); ",
+        # because DF:Natural doesn't die on parse failure
+        "die \"Can't parse date '\".$dt.\"': \".\$p->error unless \$p->success; ",
         ($coerce_to eq 'float(epoch)' ? "\$res = \$res->epoch; " :
              $coerce_to eq 'Time::Moment' ? "\$res = Time::Moment->from_object(\$res); " :
              $coerce_to eq 'DateTime' ? "" :
@@ -60,13 +62,13 @@ Data::Sah::Coerce::perl::date::str_natural - Coerce date from string parsed by D
 
 =head1 VERSION
 
-This document describes version 0.003 of Data::Sah::Coerce::perl::date::str_natural (from Perl distribution Data-Sah-Coerce-perl-date-str_natural), released on 2016-06-14.
+This document describes version 0.004 of Data::Sah::Coerce::perl::date::str_natural (from Perl distribution Data-Sah-Coerce-perl-date-str_natural), released on 2016-06-30.
 
 =head1 DESCRIPTION
 
 The rule is not enabled by default. You can enable it in a schema using e.g.:
 
- ["array*", of=>"date", "x.perl.coerce_to"=>"DateTime", "x.perl.coerce_rules"=>["str_natural"]]
+ ["date", "x.perl.coerce_rules"=>["str_natural"]]
 
 =for Pod::Coverage ^(meta|coerce)$
 
